//
//  UHF_iOS_DemoViewController.m
//  UHF_iOS_Demo
//
//  Copyright 2010-2011 Cathexis Innovations Inc. All rights reserved.
//

#import "UHF_iOS_DemoViewController.h"
#import <IDBLUE/SendStatus.h>

@implementation UHF_iOS_DemoViewController


- (void)didReceiveMemoryWarning {
    // Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
    
    // Release any cached data, images, etc that aren't in use.
}

#pragma mark - View lifecycle

// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
- (void)viewDidLoad {
    
    [super viewDidLoad];
    
    if (!_activityIndicator) {
        _activityIndicator = [[UIActivityIndicatorView alloc] initWithActivityIndicatorStyle:UIActivityIndicatorViewStyleWhiteLarge];
    
        _activityIndicator.frame = CGRectMake(0.0, 0.0, 40.0, 40.0);
        _activityIndicator.center = self.view.center;
        [self.view addSubview: _activityIndicator];
    }
}

- (void)viewDidUnload {
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}


-(IBAction) readBtnClicked: (id) sender {
    [_epcField setText:@""];
    [_activityIndicator startAnimating];
    IDBlueSdk* sdk = [self sdk];
    SendStatus* status = [sdk beginCommands:self];
    status = [sdk readTagId:self];
    NSLog(@"%@", [status message]);
}

-(IBAction) writeBtnClicked: (id) sender {
    
    RfidTag* epc = [self getEpc];
    NSString* epcString = [epc toString];
    if (epcString.length != 24)
    {
        UIAlertView *inputError = [[UIAlertView alloc] initWithTitle: @"EPC Input error" message: @"Must be 24 characters." delegate: self cancelButtonTitle: @"Ok" otherButtonTitles: nil];
        
        [inputError show];
    }
    else
    {
        [_activityIndicator startAnimating];
        IDBlueSdk* sdk = [self sdk];
        SendStatus* status = [sdk beginCommands:self];
        status = [sdk epcWriteTagId:epc withHandler:self];
        NSLog(@"%@", [status message]);
    }
}

-(IDBlueSdk*) sdk {
    UIApplication* app = [UIApplication sharedApplication];
    return (IDBlueSdk*)[app delegate];
}

-(void) setEpc:(RfidTag*) tag {
    NSString* epc = [tag toString];
    [_epcField setText:epc];
}

-(RfidTag*) getEpc {
    NSString* epc = [_epcField text];
    RfidTag* tag = [[RfidTag alloc] initWithHexString:epc];
    return tag;
}

-(void) readTagIdResponse: (IDBlueCommand*) command withResponse: (ReadTagIdResponse*) response {
    [_activityIndicator stopAnimating];
    IDBlueSdk* sdk = [self sdk];
    
    if (![response async]) {
        [sdk endCommands:true withHandler:self];
    }
    
    RfidTag* tag = [response rfidTag];
    [self setEpc:tag];
}

-(void) readTagIdFailed: (IDBlueCommand*) command withResponse: (NackResponse*) response {
    [_activityIndicator stopAnimating];
    IDBlueSdk* sdk = [self sdk];
    [sdk endCommands:false withHandler:self];
    
    UIAlertView *readError = [[UIAlertView alloc] initWithTitle: @"Read error" message: @"Could not read EPC ID.  Please try again" delegate: self cancelButtonTitle: @"Ok" otherButtonTitles: nil];
    
    [readError show];
}

-(void) epcWriteResponse: (IDBlueCommand*) command withResponse: (EpcWriteTagResponse*) response {
    [_activityIndicator stopAnimating];
    IDBlueSdk* sdk = [self sdk];
    [sdk endCommands:true withHandler:self];
    
    UIAlertView *writeMessage = [[UIAlertView alloc] initWithTitle: @"Write Successful" message: nil delegate: self cancelButtonTitle: @"Ok" otherButtonTitles: nil];
    
    [writeMessage show];
}

-(void) epcWriteFailed: (IDBlueCommand*) command withResponse: (NackResponse*) response {
    [_activityIndicator stopAnimating];
    IDBlueSdk* sdk = [self sdk];
    [sdk endCommands:false withHandler:self];
    
    UIAlertView *writeError = [[UIAlertView alloc] initWithTitle: @"Write error" message: @"Could not write EPC ID.  Please try again" delegate: self cancelButtonTitle: @"Ok" otherButtonTitles: nil];
    
    [writeError show];
}

-(void) onSessionOpened: (id) session {
    NSLog(@"Session opened");
}

-(void) onSessionOpening: (id) session {
}

-(void) onSessionOpenFailed: (id) session {
}

-(void) onSessionClosed: (id) session {
    NSLog(@"Session closed");
}

-(void) onSessionClosing: (id) session {
}

-(void) onSessionCloseFailed: (id) session {
}

-(void) onIDBlueDeviceAdded: (id) device {
    NSLog(@"IDBlue Device Added");
    [[self sdk] open];
}

-(void) onIDBlueDeviceRemoved: (id) device {
}

@end
